# bundle marked loader for webpack

Fork of [https://github.com/webpack/bundle-loader](https://github.com/webpack/bundle-loader)

## Usage

[Documentation: Using loaders](http://webpack.github.io/docs/using-loaders.html)

``` javascript
// The chunk is requested, when you require the bundle
var waitForChunk = require("bundle!./file.js");

console.assert(waitForChunk.__asyncModule === true); // function is marked with `__asyncModule` flag

// To wait until the chunk is available (and get the exports)
//  you need to async wait for it.
waitForChunk(
	function(file) {
		// use file like is was required with
		// var file = require("./file.js");
	},
	function(error) {
		// error while loading chunk (error callback is only available in webpack >= 2.2.0)
	}
);
// wraps the require in a require.ensure block
```

The file is requested when you require the bundle loader. If you want it to request it lazy, use:

``` javascript
var load = require("bundle?lazy!./file.js");

console.assert(load.__asyncModule === true); // function is marked with `__asyncModule` flag
console.assert(load.__lazyModule === true); // function is marked with `__lazyModule` flag

// The chunk is not requested until you call the load function
load(
	function(file) {
	},
	function(error) {
		// error while loading chunk (error callback is only available in webpack >= 2.2.0)
	}
);
```

You may set name for bundle (`name` query parameter). See [documentation](https://github.com/webpack/loader-utils#interpolatename).

``` javascript
require("bundle?lazy&name=my-chunk!./file.js");
```

## License

MIT (http://www.opensource.org/licenses/mit-license.php)
